import { Builder } from '@pallad/builder';
import * as boom from '@hapi/boom';
import { ErrorOutput } from './ErrorOutput';
export declare class ErrorMapperBuilder extends Builder {
    private options;
    private errorMappers;
    private onUnknownErrorListeners;
    private outputTransformers;
    constructor(options: ErrorMapperBuilder.Options);
    static fromEnv(): ErrorMapperBuilder;
    onUnknownError(listener: ErrorMapperBuilder.UnknownErrorListener): this;
    registerErrorMapper<T extends Error>(mapper: ErrorMapperBuilder.ErrorMapper): this;
    registerOutputTransformer(outputTransformer: ErrorMapperBuilder.OutputTransformer): this;
    get(): ErrorMapperBuilder.Mapper;
}
export declare namespace ErrorMapperBuilder {
    interface Options {
        /**
         * Whether to include stack trace in every error
         */
        showStackTrace: boolean;
        /**
         * Whether to show message of critical error
         */
        showUnknownErrorMessage: boolean;
    }
    interface ErrorMapper {
        (error: Error): boom.Boom | undefined;
    }
    interface UnknownErrorListener {
        (error: Error): void;
    }
    interface OutputTransformer {
        (output: ErrorOutput, error: Error, boomedError?: boom.Boom): ErrorOutput;
    }
    interface Mapper {
        (error: Error): ErrorOutput;
    }
}
